@@ -5,5 +5,6 @@ Users can use these built in methods as opposed to constructing buffers, buffer
 entities, and geometries manually.
 """
 
-from .geometry_creation import build_geometry_patch, build_entity, create_instances, update_entity, add_instances
-from .geometry_objects import AttributeInput, GeometryPatchInput
\ No newline at end of file
+from .geometry_creation import build_geometry_patch, build_entity, create_instances, update_entity, add_instances, geometry_from_mesh, export_mesh
+from .geometry_objects import AttributeInput, GeometryPatchInput
+from .byte_server import ByteServer
